@@ -19,7 +19,7 @@ from ansurr.functions import check_quiet_print
 from datetime import datetime
 
 sys.tracebacklimit = 0
-version = "0.0.33"
+version = "0.0.34"
 
 natsort = lambda s: [int(t) if t.isdigit() else t.lower() for t in re.split('(\d+)', s)]
 
@@ -30,6 +30,7 @@ def main():
     parser.add_argument("-s", "--shifts", type=str, help="input shifts file in NEF format",required=True)
     parser.add_argument("-l", "--lig", help=" include free ligands when computing flexibility", action="store_true")
     parser.add_argument("-n", "--nonstd", help="include non-standard residues when computing flexibility", action="store_true")
+    parser.add_argument("-m", "--min", help="output only scores in a text file", action="store_true")
     parser.add_argument("-o", "--olig", help="combine chains into a single structure when calculating flexibility", action="store_true")
     parser.add_argument("-q", "--quiet", help="supress output to the terminal", action="store_true")
     parser.add_argument("-r", "--reref", help="re-reference shifts using PANAV before calculating RCI (requires Java)",action="store_true")
@@ -48,14 +49,19 @@ def main():
     check_quiet_print(args.quiet," -> pdb: "+path_to_pdb)
     check_quiet_print(args.quiet," -> shifts: "+path_to_shifts)
 
-    output_dir = os.path.join(os.getcwd(), pdb_file+'_'+shift_file)
+    if args.min:
+        output_dir = 'ansurr_tmp'
+    else:
+        output_dir = os.path.join(os.getcwd(), pdb_file+'_'+shift_file)
 
     if os.path.isdir(output_dir):
         shutil.rmtree(output_dir)
-        check_quiet_print(args.quiet," -> overwriting output directory: "+output_dir)
+        if not args.min:
+            check_quiet_print(args.quiet," -> overwriting output directory: "+output_dir)
     else:
-        check_quiet_print(args.quiet," -> output directory: "+output_dir)
-    os.makedirs(output_dir)  
+        if not args.min:
+            check_quiet_print(args.quiet," -> output directory: "+output_dir)
+    os.makedirs(output_dir)   
 
     check_quiet_print(args.quiet,"calculating RCI")
     chain_output_rci = rci_nef.calc_RCI(path_to_shifts,output_dir+'/other_output/',panav=args.reref,quiet=args.quiet)
@@ -133,6 +139,11 @@ def main():
         check_quiet_print(args.quiet," -> CRITICAL ERROR failed to calculate any validation scores, exiting")
         sys.exit(1)
 
+    if args.min:
+        check_quiet_print(args.quiet,' -> scores saved to scores_'+pdb_file+'_'+shift_file+'.out')
+        shutil.move(output_dir+'/ANSURR_output/scores.out','scores_'+pdb_file+'_'+shift_file+'.out')
+        shutil.rmtree(output_dir)
+
     check_quiet_print(args.quiet,"")
     sys.exit(0)
 
